@@ -17,7 +17,6 @@ import logging
 import re
 from tempfile import TemporaryFile
 
-from datalad.cmd import GitWitlessRunner
 from datalad.interface.base import (
     Interface,
     build_doc,
@@ -46,7 +45,7 @@ from datalad.support.constraints import (
 from datalad.support.exceptions import CommandError
 from datalad.utils import (
     Path,
-    assure_list,
+    ensure_list,
 )
 
 from datalad.distribution.dataset import (
@@ -198,7 +197,7 @@ class Push(Interface):
             raise ValueError("'since' should point to commitish or use '^'.")
         # we resolve here, because we need to perform inspection on what was given
         # as an input argument further down
-        paths = [resolve_path(p, dataset) for p in assure_list(path)]
+        paths = [resolve_path(p, dataset) for p in ensure_list(path)]
 
         ds = require_dataset(
             dataset, check_installed=True, purpose='pushing')
@@ -315,10 +314,11 @@ def _datasets_since_(dataset, since, paths, recursive, recursion_limit):
             recursion_limit=recursion_limit,
             # make it as fast as possible
             eval_file_type=False,
-            # we relay on all records of a dataset coming out
-            # in succession, with no interuption by records
-            # concerning subdataset content
-            reporting_order='breadth-first'):
+            # TODO?: expose order as an option for diff and push
+            # since in some cases breadth-first would be sufficient
+            # and result in "taking action faster"
+            reporting_order='bottom-up'
+    ):
         if res.get('action', None) != 'diff':
             # we don't care right now
             continue
@@ -332,9 +332,9 @@ def _datasets_since_(dataset, since, paths, recursive, recursion_limit):
                 'Cannot handle diff result without a parent dataset '
                 'property: {}'.format(res))
         if res.get('type', None) == 'dataset':
-            # a subdataset record in another data
+            # a subdataset record in another dataset
             # this could be here, because
-            # - this dataset with explicitely requested by path
+            # - this dataset was explicitly requested by path
             #   -> should get a dedicated dataset record -- even without recursion
             # - a path within an existing subdataset was given
             # - a path within an non-existing subdataset was given
@@ -387,7 +387,7 @@ def _push(dspath, content, target, data, force, jobs, res_kwargs, pbars,
 
     res_kwargs.update(type='dataset', path=dspath)
 
-    # content will be unique for every push (even on the some dataset)
+    # content will be unique for every push (even on the same dataset)
     pbar_id = 'push-{}-{}'.format(target, id(content))
     # register for final orderly take down
     pbars[pbar_id] = ds
@@ -460,7 +460,7 @@ def _push(dspath, content, target, data, force, jobs, res_kwargs, pbars,
     depvar = 'remote.{}.datalad-publish-depends'.format(target)
     # list of remotes that are publication dependencies for the
     # target remote
-    publish_depends = assure_list(ds.config.get(depvar, []))
+    publish_depends = ensure_list(ds.config.get(depvar, []))
     if publish_depends:
         lgr.debug("Discovered publication dependencies for '%s': %s'",
                   target, publish_depends)
@@ -792,8 +792,7 @@ def _push_data(ds, target, content, data, force, jobs, res_kwargs,
                 message='Slated for transport, but no content present',
             )
 
-    cmd = ['git', 'annex', 'copy', '--batch', '-z', '--to', target,
-           '--json', '--json-error-messages', '--json-progress']
+    cmd = ['copy', '--batch', '-z', '--to', target]
 
     if jobs:
         cmd.extend(['--jobs', str(jobs)])
@@ -847,26 +846,15 @@ def _push_data(ds, target, content, data, force, jobs, res_kwargs,
         # rewind stdin buffer
         file_list.seek(0)
 
-        # tailor the progress protocol with the total number of files
-        # to be transferred
-        class TailoredPushAnnexJsonProtocol(AnnexJsonProtocol):
-            total_nbytes = nbytes
-
         # and go
-        # TODO try-except and yield what was captured before the crash
-        #res = GitWitlessRunner(
-        res = GitWitlessRunner(
-            cwd=ds.path,
-        ).run(
+        res = ds_repo._call_annex_records(
             cmd,
-            # TODO report how many in total, and give global progress too
-            protocol=TailoredPushAnnexJsonProtocol,
-            stdin=file_list)
-        for c in ('stdout', 'stderr'):
-            if res[c]:
-                lgr.debug('Received unexpected %s from `annex copy`: %s',
-                          c, res[c])
-        for j in res['stdout_json']:
+            stdin=file_list,
+            progress=True,
+            # tailor the progress protocol with the total number of files
+            # to be transferred
+            total_nbytes=nbytes)
+        for j in res:
             yield annexjson2result(j, ds, type='file', **res_kwargs)
 
     for annex_key, paths in repkey_paths.items():
